# Orthophoto segmentation

[![Actions Status](https://github.com/orthoseg/orthoseg/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/orthoseg/orthoseg/actions?query=workflow%3ATests) 
[![PyPI version](https://img.shields.io/pypi/v/orthoseg.svg)](https://pypi.org/project/orthoseg)
[![DOI](https://zenodo.org/badge/147507046.svg)](https://zenodo.org/doi/10.5281/zenodo.10340584)

This project provides a procedure and software to make it easy to:
1. create a training dataset for a topic of your choice
2. train a neural network to segment orthophotos
3. run the segmentation on a larger area + vectorize the result
4. apply some basic postprocessing like dissolve,...

Only open source software is needed, eg. QGIS and tensorflow.

Installation and usage instructions can be found in the [orthoseg wiki](https://github.com/orthoseg/orthoseg/wiki)
